import { TTLParser } from "../ttl.js";
class InMemorySessionRepository {
    static sessions = new Map();
    #ttl;
    constructor(options) {
        this.#ttl = new TTLParser(options.ttl);
    }
    ttl() {
        return this.#ttl;
    }
    async exists(sessionKey) {
        return InMemorySessionRepository.sessions.has(sessionKey);
    }
    async initializeSession(sessionKey) {
        InMemorySessionRepository.sessions.set(sessionKey, {
            expiration: Date.now() + this.#ttl.toMilliSecond(),
            data: null
        });
    }
    async loadValue(sessionKey) {
        return InMemorySessionRepository.sessions.get(sessionKey)?.data ?? null;
    }
    async storeValue(sessionKey, value) {
        const session = InMemorySessionRepository.sessions.get(sessionKey);
        if (session) {
            InMemorySessionRepository.sessions.set(sessionKey, {
                ...session,
                data: value
            });
        }
    }
    async destroySession(sessionKey) {
        InMemorySessionRepository.sessions.delete(sessionKey);
    }
    async purgeExpired() {
        InMemorySessionRepository.sessions.forEach((_, sessionKey) => {
            const expiration = InMemorySessionRepository.sessions.get(sessionKey).expiration;
            if (!expiration || Date.now() > expiration) {
                this.destroySession(sessionKey);
            }
        });
    }
}
export { InMemorySessionRepository };
